summaryrefslogtreecommitdiffstats
path: root/Include/sliceobject.h
diff options
context:
space:
mode:
Diffstat (limited to 'Include/sliceobject.h')
-rw-r--r--Include/sliceobject.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/Include/sliceobject.h b/Include/sliceobject.h
index ac7cd13..6ee4698 100644
--- a/Include/sliceobject.h
+++ b/Include/sliceobject.h
@@ -4,12 +4,12 @@
extern "C" {
#endif
-/* The unique ellipses object "..." */
+/* The unique ellipsis object "..." */
-extern DL_IMPORT(PyObject) _Py_EllipsesObject; /* Don't use this directly */
-
-#define Py_Ellipses (&_Py_EllipsesObject)
+extern DL_IMPORT(PyObject) _Py_EllipsisObject; /* Don't use this directly */
+#define Py_Ellipsis (&_Py_EllipsisObject)
+#define Py_Ellipses Py_Ellipsis /* For bad spellers like me :-( */
/* Slice object interface */